==> fields_1.7.2.tar.gz: fields/R/ozone.R <==
"ozone" <-
structure(list(x = structure(c(10.2420950223404, 3.80376523711237, 
9.10894898014071, 9.62401536295848, -2.42853799498812, -12.626852374789, 
-0.419779101996896, -7.88824165286121, 3.54623204570348, -16.9019033521803, 
-27.2032310085453, -6.18852258956094, -5.26140310048807, -12.2147992685346, 
-25.5550185835271, -15.6657440334172, 21.109995699806, 12.9204402129956, 
33.8836419936979, 28.1148985061338, -8.81404505952784, 6.475624941694, 
-12.2040623901154, -18.5689928883614, 6.8907291046231, -14.9714234763093, 
-2.03401039835273, 10.6958505981398, 12.287083222701, -4.939739538856, 
11.4568748968428, 20.2432463455088, 35.0486281566463, 28.0610414140067, 
23.2873435403219, -20.2294095400778, -19.6759373228389, -16.9777602637997, 
-17.5312324810386, -18.4998088612067), .Dim = c(20, 2), .Dimnames = list(
    c("170310032", "170310037", "170310050", "170311002", "170311003", 
    "170311601", "170314002", "170314003", "170317002", "170436001", 
    "170890005", "170970001", "170971002", "170973001", "171110001", 
    "171971008", "180891016", "180892008", "181270020", "181270024"
    ), c("East.West", "North.South"))), y = c(36.4902936963152, 
34.6396930821552, 31.6444005657229, 34.4646956838262, 37.7204739668803, 
40.1342965426748, 37.0181086910068, 38.4001686365134, 44.0485589002946, 
38.4870329290307, 42.2402282830657, 40.0049235817847, 42.1090485712195, 
39.6319596353327, 42.8054712629932, 44.1097465187358, 35.1186331327201, 
46.898470931915, 42.9564231070325, 46.6868555984414), lon.lat = structure(c(-87.546, 
-87.671, -87.568, -87.558, -87.792, -87.99, -87.753, -87.898, 
-87.676, -88.073, -88.273, -87.865, -87.847, -87.982, -88.241, 
-88.049, -87.335, -87.494, -87.087, -87.199, 41.757, 41.978, 
41.708, 41.616, 41.984, 41.668, 41.855, 42.039, 42.062, 41.813, 
42.05, 42.177, 42.391, 42.29, 42.221, 41.592, 41.6, 41.639, 41.631, 
41.617), .Dim = c(20, 2), .Dimnames = list(c("170310032", "170310037", 
"170310050", "170311002", "170311003", "170311601", "170314002", 
"170314003", "170317002", "170436001", "170890005", "170970001", 
"170971002", "170973001", "171110001", "171971008", "180891016", 
"180892008", "181270020", "181270024"), c("lat", "lon")))), .Names = c("x", 
"y", "lon.lat"))

==> fields_3.3.1.tar.gz: fields/R/ozone.R <==
"ozone" <-
structure(list(x = structure(c(10.2420950223404, 3.80376523711237, 
9.10894898014071, 9.62401536295848, -2.42853799498812, -12.626852374789, 
-0.419779101996896, -7.88824165286121, 3.54623204570348, -16.9019033521803, 
-27.2032310085453, -6.18852258956094, -5.26140310048807, -12.2147992685346, 
-25.5550185835271, -15.6657440334172, 21.109995699806, 12.9204402129956, 
33.8836419936979, 28.1148985061338, -8.81404505952784, 6.475624941694, 
-12.2040623901154, -18.5689928883614, 6.8907291046231, -14.9714234763093, 
-2.03401039835273, 10.6958505981398, 12.287083222701, -4.939739538856, 
11.4568748968428, 20.2432463455088, 35.0486281566463, 28.0610414140067, 
23.2873435403219, -20.2294095400778, -19.6759373228389, -16.9777602637997, 
-17.5312324810386, -18.4998088612067), .Dim = as.integer(c(20, 
2)), .Dimnames = list(c("170310032", "170310037", "170310050", 
"170311002", "170311003", "170311601", "170314002", "170314003", 
"170317002", "170436001", "170890005", "170970001", "170971002", 
"170973001", "171110001", "171971008", "180891016", "180892008", 
"181270020", "181270024"), c("East.West", "North.South"))), y = c(36.4902936963152, 
34.6396930821552, 31.6444005657229, 34.4646956838262, 37.7204739668803, 
40.1342965426748, 37.0181086910068, 38.4001686365134, 44.0485589002946, 
38.4870329290307, 42.2402282830657, 40.0049235817847, 42.1090485712195, 
39.6319596353327, 42.8054712629932, 44.1097465187358, 35.1186331327201, 
46.898470931915, 42.9564231070325, 46.6868555984414), lon.lat = structure(c(-87.546, 
-87.671, -87.568, -87.558, -87.792, -87.99, -87.753, -87.898, 
-87.676, -88.073, -88.273, -87.865, -87.847, -87.982, -88.241, 
-88.049, -87.335, -87.494, -87.087, -87.199, 41.757, 41.978, 
41.708, 41.616, 41.984, 41.668, 41.855, 42.039, 42.062, 41.813, 
42.05, 42.177, 42.391, 42.29, 42.221, 41.592, 41.6, 41.639, 41.631, 
41.617), .Dim = as.integer(c(20, 2)), .Dimnames = list(c("170310032", 
"170310037", "170310050", "170311002", "170311003", "170311601", 
"170314002", "170314003", "170317002", "170436001", "170890005", 
"170970001", "170971002", "170973001", "171110001", "171971008", 
"180891016", "180892008", "181270020", "181270024"), c("lat", 
"lon")))), .Names = c("x", "y", "lon.lat"))
